@@ -57,7 +57,8 @@ SnapshotReporter <- R6::R6Class("SnapshotReporter",
           x = old,   x_arg = "old",
           y = value, y_arg = "new",
           ...,
-          tolerance = tolerance
+          tolerance = tolerance,
+          quote_strings = FALSE
         )
 
         if (length(comp) > 0L) {
@@ -101,6 +102,7 @@ SnapshotReporter <- R6::R6Class("SnapshotReporter",
       snapshot_file_equal(
         snap_test_dir = snap_dir,
         snap_name = name,
+        snap_variant = variant,
         path = path,
         file_equal = file_equal,
         fail_on_new = self$fail_on_new,
